@@ -8,8 +8,7 @@ import binascii
 import hashlib
 import logging
 import hmac
-import sys
-
+import urlparse
 
 try:
 	import timemodule as time
@@ -92,7 +91,9 @@ class ScalrConnection(object):
 				resp_body = e.read() if e.fp is not None else ""
 				raise ScalrAPIError("Request failed. %s. URL: %s. Service message: %s" % (e, self.environment.url, resp_body))
 			else:
-				host, port = splitnport(req.host, req.port or 443)
+				host, port = splitnport(req.host, req.port)
+				if not port:
+					port = 80 if "http" == urlparse.urlparse(self.environment.url).scheme else 443
 				raise ScalrAPIError("Cannot connect to Scalr on %s:%s. %s" 
 						% (host, port, str(e)))
 		except BaseException,e:
@@ -580,11 +581,14 @@ class ScalrConnection(object):
 		
 		params['FarmID'] = farm_id
 		roles = self._request(command="FarmGetDetails", params=params, response_reader=self._read_get_farm_role_properties_response)
+
 		servers = []
 		for role in roles:
+
 			if role.servers:
 				for server in role.servers:
 					server.name = role.name
+					server.alias = role.alias
 					server.farm_role_id = role.farm_role_id
 					servers.append(server)
 
@@ -656,13 +660,17 @@ class ScalrConnection(object):
 		return self._request("EnvironmentsList", response_reader=self._read_list_environments_response)
 
 
-	def create_farm(self, name, descr=None):
+	def create_farm(self, name, descr=None, project_id=None, config=None):
 		"""
 		@return FarmID
 		"""
 		params = {'Name': name}
 		if descr:
 			params['Description'] = descr
+		if project_id:
+			params['ProjectID'] = project_id
+		if config:
+			params['Configuration'] = config
 
 		return self._request(command="FarmCreate", params=params, response_reader=self._read_create_farm_response)
 
